@@ -20,7 +20,8 @@
 
 #ifndef BLUEDEVIL_SYSTEM_CHECK_H
 #define BLUEDEVIL_SYSTEM_CHECK_H
-#include <QtCore/QObject>
+
+#include <QObject>
 
 class QVBoxLayout;
 
@@ -35,6 +36,17 @@ public:
     SystemCheck(QWidget *parent);
     virtual ~SystemCheck();
 
+    struct SystemCheckResult {
+        enum Result {
+            NoWarnings = 0,
+            BluetoothDisabled,
+            NoAdapters,
+            NotificationsDisabled,
+            DefaultAdapterHidden
+        } result;
+        QWidget *warningWidget;
+    };
+
     void createWarnings(QVBoxLayout *layout);
 
     bool checkKDEDModuleLoaded();
@@ -49,7 +61,6 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void fixNoKDEDRunning();
-    void fixNoUsableAdapterError();
     void fixNotDiscoverableAdapterError();
     void fixDisabledNotificationsError();
 
@@ -57,7 +68,6 @@ private:
     KDED        *m_kded;
     QWidget     *m_parent;
     KMessageWidget *m_noAdaptersError;
-    KMessageWidget *m_noUsableAdapterError;
     KMessageWidget *m_noKDEDRunning;
     KMessageWidget *m_notDiscoverableAdapterError;
     KMessageWidget *m_disabledNotificationsError;
